@@ -1,5 +1,5 @@
 from .schema_builder import geom, point
-from .trx import insert_point, update, delete
+from .trx import insert_point, update, delete, get_container
 
 
 all = (
@@ -8,4 +8,5 @@ all = (
     'insert_point',
     'update',
     'delete',
+    'get_container',
 )
