@@ -44,3 +44,19 @@ def delete(*,
             builder.filter(fid)))
             
 
+def get_container(
+    namespaces: List[dict],
+    typeName: str,
+    geom_prop: str,
+    point: Tuple[float, float],  
+):
+    return builder.get_feature(
+        namespaces=namespaces,
+        value=builder.query(
+            typeName=typeName,
+            value=builder.contains(
+                geom_prop=geom_prop,
+                geom=builder.point(coordinates=point, srs=3857)
+            )
+        )
+    )
\ No newline at end of file
